import { defineComponent, provide } from '@vue/composition-api';
import mapboxgl from 'mapbox-gl';
import Deferred from 'my-deferred';
import { n as normalizeComponent } from '../_chunks/normalize-component.d57baabe.js';

var getMapboxOptions = function getMapboxOptions(props, el) {
  return {
    accessToken: props.accessToken,
    container: props.container || el,
    style: props.mapStyle
  };
};

var script = defineComponent({
  props: {
    accessToken: {
      type: String,
      default: ''
    },
    height: {
      type: String,
      default: '500px'
    },
    width: {
      type: String,
      default: '100%'
    },
    container: {
      type: [Object, String] || String,
      default: ''
    },
    minZoom: {
      type: Number,
      default: 0
    },
    maxZoom: {
      type: Number,
      default: 22
    },
    minPitch: {
      type: Number,
      default: 0
    },
    maxPitch: {
      type: Number,
      default: 60
    },
    mapStyle: {
      type: [Object, String],
      default: 'mapbox://styles/mapbox/streets-v11'
    },
    hash: {
      type: Boolean,
      default: false
    },
    interactive: {
      type: Boolean,
      default: true
    },
    bearingSnap: {
      type: Number,
      default: 7
    },
    pitchWithRotate: {
      type: Boolean,
      default: true
    },
    clickTolerance: {
      type: Number,
      default: 3
    },
    attributionControl: {
      type: Boolean,
      default: true
    },
    customAttribution: {
      type: Array,
      default: null
    },
    logoPosition: {
      type: String,
      default: 'bottom-left'
    },
    failIfMajorPerformanceCaveat: {
      type: Boolean,
      default: false
    },
    preserveDrawingBuffer: {
      type: Boolean,
      default: false
    },
    antialias: {
      type: Boolean,
      default: false
    },
    refreshExpiredTiles: {
      type: Boolean,
      default: true
    },
    maxBounds: {
      type: Array,
      default: undefined
    },
    scrollZoom: {
      type: [Boolean, Object],
      default: true
    },
    boxZoom: {
      type: Boolean,
      default: true
    },
    dragRotate: {
      type: Boolean,
      default: true
    },
    dragPan: {
      type: [Object, Boolean],
      default: true
    },
    keyboard: {
      type: Boolean,
      default: true
    },
    doubleClickZoom: {
      type: Boolean,
      default: true
    },
    touchZoomRotate: {
      type: [Boolean, Object],
      default: true
    },
    trackResize: {
      type: Boolean,
      default: true
    },
    center: {
      type: [Object, Array],
      default: function _default() {
        return [0, 0];
      }
    },
    zoom: {
      type: Number,
      default: 0
    },
    bearing: {
      type: Number,
      default: 0
    },
    pitch: {
      type: Number,
      default: 0
    },
    bounds: {
      type: Array,
      default: undefined
    },
    fitBoundsOptions: {
      type: Object,
      default: null
    },
    renderWorldCopies: {
      type: Boolean,
      default: true
    },
    maxTileCacheSize: {
      type: Number,
      default: null
    },
    localIdeographFontFamily: {
      type: String,
      default: 'sans-serif'
    },
    transformRequest: {
      type: Function,
      default: null
    },
    collectResourceTiming: {
      type: Boolean,
      default: false
    },
    fadeDuration: {
      type: Number,
      default: 300
    },
    crossSourceCollisions: {
      type: Boolean,
      default: true
    }
  },
  setup: function setup(props) {
    var $map = new Deferred();
    provide('$map', $map);
    return {
      $map: $map
    };
  },
  mounted: function mounted() {
    var _this = this;

    var options = getMapboxOptions(this.$props, this.$el);

    if (!options.accessToken) {
      throw new Error('No Access Token provided');
    }

    mapboxgl.accessToken = options.accessToken;
    var map = new mapboxgl.Map(options);
    map.on('load', function () {
      _this.$map.resolve(map);
    });
  },
  computed: {
    style: function style() {
      return {
        height: this.height,
        width: this.width
      };
    }
  }
});

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    style: _vm.style
  }, [_vm.$map.isResolved ? _c('div', [_vm._t("default")], 2) : _c('div', [_vm._t("loader", [_c('div', {
    style: _vm.style
  })])], 2)]);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* module identifier */

var __vue_module_identifier__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

export default __vue_component__;
//# sourceMappingURL=MapboxMap.ts.map
