import { defineComponent, provide } from '@vue/composition-api';
import { Marker } from 'mapbox-gl';
import { n as normalizeComponent } from '../_chunks/normalize-component.d57baabe.js';
import Deferred from 'my-deferred/dist/src';
import injectMap from '../shared/map.ts';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

var getMarkerOptions = function getMarkerOptions(props) {
  var element = props.element,
      offset = props.offset,
      anchor = props.anchor,
      color = props.color,
      draggable = props.draggable,
      clickTolerance = props.clickTolerance,
      rotation = props.rotation,
      rotationAlignment = props.rotationAlignment,
      pitchAlignment = props.pitchAlignment,
      scale = props.scale;
  return {
    element: element,
    offset: offset,
    anchor: anchor,
    color: color,
    draggable: draggable,
    clickTolerance: clickTolerance,
    rotation: rotation,
    rotationAlignment: rotationAlignment,
    pitchAlignment: pitchAlignment,
    scale: scale
  };
};

var script = defineComponent({
  props: {
    lngLat: {
      // type: Array as () => Array<number>,
      default: function _default() {
        return [0, 0];
      } // required: true,

    },
    element: {
      type: HTMLElement,
      default: null
    },
    offset: {
      type: [Array],
      default: function _default() {
        return [0, 0];
      }
    },
    anchor: {
      type: String,
      default: function _default() {
        return 'left';
      }
    },
    color: {
      type: String,
      default: null
    },
    scale: {
      type: Number,
      default: 1
    },
    draggable: {
      type: Boolean,
      default: false
    },
    rotation: {
      type: Number,
      default: 0
    },
    pitchAlignment: {
      type: String,
      default: 'auto'
    },
    rotationAlignment: {
      type: String,
      default: 'auto'
    }
  },
  setup: function setup() {
    var $map = injectMap.setup().$map;
    var $marker = new Deferred();
    provide('$marker', $marker);
    return {
      $map: $map,
      $marker: $marker
    };
  },
  mounted: function mounted() {
    return __awaiter(this, void 0, void 0, function () {
      var map, options, marker;
      return __generator(this, function (_a) {
        switch (_a.label) {
          case 0:
            return [4
            /*yield*/
            , this.$map.promise];

          case 1:
            map = _a.sent();
            options = getMarkerOptions(this.$props);
            marker = new Marker(options).setLngLat(this.lngLat).addTo(map);
            this.$marker.resolve(marker);
            return [2
            /*return*/
            ];
        }
      });
    });
  }
});

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div');
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* module identifier */

var __vue_module_identifier__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

export default __vue_component__;
//# sourceMappingURL=MapboxMarker.ts.map
